/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsISOAPTransportListener.idl
 */

#ifndef __gen_nsISOAPTransportListener_h__
#define __gen_nsISOAPTransportListener_h__

#include "nsISupports.h"

class nsIDOMDocument; /* forward declaration */


/* starting interface:    nsISOAPTransportListener */
#define NS_ISOAPTRANSPORTLISTENER_IID_STR "99ec6696-535f-11d4-9a58-000064657374"

#define NS_ISOAPTRANSPORTLISTENER_IID \
  {0x99ec6696, 0x535f, 0x11d4, \
    { 0x9a, 0x58, 0x00, 0x00, 0x64, 0x65, 0x73, 0x74 }}

class NS_NO_VTABLE nsISOAPTransportListener : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_ISOAPTRANSPORTLISTENER_IID)

  /**
   * This method is invoked when an ansynchronous response is
   * completed. The listener is registered as part of the original
   * call to the transport.
   *
   * @param document The XML document that is the body of the response
   * @param status The protocol status returned
   * @param result The call result
   */
  /* void handleResponse (in nsIDOMDocument document, in unsigned long status, in nsresult result); */
  NS_IMETHOD HandleResponse(nsIDOMDocument *document, PRUint32 status, nsresult result) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSISOAPTRANSPORTLISTENER \
  NS_IMETHOD HandleResponse(nsIDOMDocument *document, PRUint32 status, nsresult result); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSISOAPTRANSPORTLISTENER(_to) \
  NS_IMETHOD HandleResponse(nsIDOMDocument *document, PRUint32 status, nsresult result) { return _to ## HandleResponse(document, status, result); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsSOAPTransportListener : public nsISOAPTransportListener
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSISOAPTRANSPORTLISTENER

  nsSOAPTransportListener();
  virtual ~nsSOAPTransportListener();
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsSOAPTransportListener, nsISOAPTransportListener)

nsSOAPTransportListener::nsSOAPTransportListener()
{
  NS_INIT_ISUPPORTS();
  /* member initializers and constructor code */
}

nsSOAPTransportListener::~nsSOAPTransportListener()
{
  /* destructor code */
}

/* void handleResponse (in nsIDOMDocument document, in unsigned long status, in nsresult result); */
NS_IMETHODIMP nsSOAPTransportListener::HandleResponse(nsIDOMDocument *document, PRUint32 status, nsresult result)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsISOAPTransportListener_h__ */
